package com.srs.staff.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import com.srs.staff.mapper.SysRfileMapper;
import com.srs.staff.domain.SysRfile;
import com.srs.staff.service.ISysRfileService;

/**
 * 文件管理Service业务层处理
 *
 * @author srs
 * @date 2024-05-16
 */
@Service
public class SysRfileServiceImpl extends ServiceImpl<SysRfileMapper,SysRfile> implements ISysRfileService {
    @Autowired
    private SysRfileMapper sysRfileMapper;

    /**
     * 查询文件管理
     *
     * @param rfileId 文件管理主键
     * @return 文件管理
     */
    @Override
    public SysRfile selectSysRfileByRfileId(Long rfileId) {
        return sysRfileMapper.selectSysRfileByRfileId(rfileId);
    }

    /**
     * 查询文件管理列表
     *
     * @param sysRfile 文件管理
     * @return 文件管理
     */
    @Override
    public List<SysRfile> selectSysRfileList(SysRfile sysRfile) {
        return sysRfileMapper.selectSysRfileList(sysRfile);
    }

    /**
     * 新增文件管理
     *
     * @param sysRfile 文件管理
     * @return 结果
     */
    @Override
    public int insertSysRfile(SysRfile sysRfile) {
            return sysRfileMapper.insertSysRfile(sysRfile);
    }

    /**
     * 修改文件管理
     *
     * @param sysRfile 文件管理
     * @return 结果
     */
    @Override
    public int updateSysRfile(SysRfile sysRfile) {
        return sysRfileMapper.updateSysRfile(sysRfile);
    }

    /**
     * 批量删除文件管理
     *
     * @param rfileIds 需要删除的文件管理主键
     * @return 结果
     */
    @Override
    public int deleteSysRfileByRfileIds(Long[] rfileIds) {
        return sysRfileMapper.deleteSysRfileByRfileIds(rfileIds);
    }

    /**
     * 删除文件管理信息
     *
     * @param rfileId 文件管理主键
     * @return 结果
     */
    @Override
    public int deleteSysRfileByRfileId(Long rfileId) {
        return sysRfileMapper.deleteSysRfileByRfileId(rfileId);
    }
}
